pub struct CConstFst(pub Box<ConstFst<TropicalWeight>>);Tuple Fields
0: Box<ConstFst<TropicalWeight>>Trait Implementations
Sourceimpl RawPointerConverter<CConstFst> for CConstFst
impl RawPointerConverter<CConstFst> for CConstFst
Sourcefn into_raw_pointer(self) -> *const CConstFst
fn into_raw_pointer(self) -> *const CConstFst
Creates a raw pointer from the value and leaks it, you should use
Self::from_raw_pointer
or Self::drop_raw_pointer to free the value when you’re done with it.Sourcefn into_raw_pointer_mut(self) -> *mut CConstFst
fn into_raw_pointer_mut(self) -> *mut CConstFst
Creates a mutable raw pointer from the value and leaks it, you should use
Self::from_raw_pointer_mut or Self::drop_raw_pointer_mut to free the value when
you’re done with it.Sourceunsafe fn from_raw_pointer_mut(
input: *mut CConstFst,
) -> Result<CConstFst, UnexpectedNullPointerError>
unsafe fn from_raw_pointer_mut( input: *mut CConstFst, ) -> Result<CConstFst, UnexpectedNullPointerError>
Takes back control of a raw pointer created by
Self::into_raw_pointer_mut. Read moreSourceunsafe fn from_raw_pointer(
input: *const CConstFst,
) -> Result<CConstFst, UnexpectedNullPointerError>
unsafe fn from_raw_pointer( input: *const CConstFst, ) -> Result<CConstFst, UnexpectedNullPointerError>
Takes back control of a raw pointer created by
Self::into_raw_pointer. Read moreSourceunsafe fn drop_raw_pointer(
input: *const T,
) -> Result<(), UnexpectedNullPointerError>
unsafe fn drop_raw_pointer( input: *const T, ) -> Result<(), UnexpectedNullPointerError>
Takes back control of a raw pointer created by
Self::into_raw_pointer and drop it. Read moreSourceunsafe fn drop_raw_pointer_mut(
input: *mut T,
) -> Result<(), UnexpectedNullPointerError>
unsafe fn drop_raw_pointer_mut( input: *mut T, ) -> Result<(), UnexpectedNullPointerError>
Takes back control of a raw pointer created by
Self::into_raw_pointer_mut and drops it. Read moreAuto Trait Implementations
impl Freeze for CConstFst
impl RefUnwindSafe for CConstFst
impl Send for CConstFst
impl Sync for CConstFst
impl Unpin for CConstFst
impl UnsafeUnpin for CConstFst
impl UnwindSafe for CConstFst