pub struct CFst(pub Box<dyn BindableFst>);Tuple Fields
0: Box<dyn BindableFst>Trait Implementations
Sourceimpl RawPointerConverter<CFst> for CFst
impl RawPointerConverter<CFst> for CFst
Sourcefn into_raw_pointer(self) -> *const CFst
fn into_raw_pointer(self) -> *const CFst
Creates a raw pointer from the value and leaks it, you should use
Self::from_raw_pointer
or Self::drop_raw_pointer to free the value when you’re done with it.Sourcefn into_raw_pointer_mut(self) -> *mut CFst
fn into_raw_pointer_mut(self) -> *mut CFst
Creates a mutable raw pointer from the value and leaks it, you should use
Self::from_raw_pointer_mut or Self::drop_raw_pointer_mut to free the value when
you’re done with it.Sourceunsafe fn from_raw_pointer_mut(
input: *mut CFst,
) -> Result<CFst, UnexpectedNullPointerError>
unsafe fn from_raw_pointer_mut( input: *mut CFst, ) -> Result<CFst, UnexpectedNullPointerError>
Takes back control of a raw pointer created by
Self::into_raw_pointer_mut. Read moreSourceunsafe fn from_raw_pointer(
input: *const CFst,
) -> Result<CFst, UnexpectedNullPointerError>
unsafe fn from_raw_pointer( input: *const CFst, ) -> Result<CFst, UnexpectedNullPointerError>
Takes back control of a raw pointer created by
Self::into_raw_pointer. Read moreSourceunsafe fn drop_raw_pointer(
input: *const T,
) -> Result<(), UnexpectedNullPointerError>
unsafe fn drop_raw_pointer( input: *const T, ) -> Result<(), UnexpectedNullPointerError>
Takes back control of a raw pointer created by
Self::into_raw_pointer and drop it. Read moreSourceunsafe fn drop_raw_pointer_mut(
input: *mut T,
) -> Result<(), UnexpectedNullPointerError>
unsafe fn drop_raw_pointer_mut( input: *mut T, ) -> Result<(), UnexpectedNullPointerError>
Takes back control of a raw pointer created by
Self::into_raw_pointer_mut and drops it. Read moreAuto Trait Implementations
impl Freeze for CFst
impl !RefUnwindSafe for CFst
impl !Send for CFst
impl !Sync for CFst
impl Unpin for CFst
impl UnsafeUnpin for CFst
impl !UnwindSafe for CFst