pub struct CVecFst(pub Box<VectorFst<TropicalWeight>>);Tuple Fields
0: Box<VectorFst<TropicalWeight>>Trait Implementations
Sourceimpl RawPointerConverter<CVecFst> for CVecFst
impl RawPointerConverter<CVecFst> for CVecFst
Sourcefn into_raw_pointer(self) -> *const CVecFst
fn into_raw_pointer(self) -> *const CVecFst
Creates a raw pointer from the value and leaks it, you should use
Self::from_raw_pointer
or Self::drop_raw_pointer to free the value when you’re done with it.Sourcefn into_raw_pointer_mut(self) -> *mut CVecFst
fn into_raw_pointer_mut(self) -> *mut CVecFst
Creates a mutable raw pointer from the value and leaks it, you should use
Self::from_raw_pointer_mut or Self::drop_raw_pointer_mut to free the value when
you’re done with it.Sourceunsafe fn from_raw_pointer_mut(
input: *mut CVecFst,
) -> Result<CVecFst, UnexpectedNullPointerError>
unsafe fn from_raw_pointer_mut( input: *mut CVecFst, ) -> Result<CVecFst, UnexpectedNullPointerError>
Takes back control of a raw pointer created by
Self::into_raw_pointer_mut. Read moreSourceunsafe fn from_raw_pointer(
input: *const CVecFst,
) -> Result<CVecFst, UnexpectedNullPointerError>
unsafe fn from_raw_pointer( input: *const CVecFst, ) -> Result<CVecFst, UnexpectedNullPointerError>
Takes back control of a raw pointer created by
Self::into_raw_pointer. Read moreSourceunsafe fn drop_raw_pointer(
input: *const T,
) -> Result<(), UnexpectedNullPointerError>
unsafe fn drop_raw_pointer( input: *const T, ) -> Result<(), UnexpectedNullPointerError>
Takes back control of a raw pointer created by
Self::into_raw_pointer and drop it. Read moreSourceunsafe fn drop_raw_pointer_mut(
input: *mut T,
) -> Result<(), UnexpectedNullPointerError>
unsafe fn drop_raw_pointer_mut( input: *mut T, ) -> Result<(), UnexpectedNullPointerError>
Takes back control of a raw pointer created by
Self::into_raw_pointer_mut and drops it. Read moreAuto Trait Implementations
impl Freeze for CVecFst
impl RefUnwindSafe for CVecFst
impl Send for CVecFst
impl Sync for CVecFst
impl Unpin for CVecFst
impl UnsafeUnpin for CVecFst
impl UnwindSafe for CVecFst