pub struct CTrsIterator(/* private fields */);Trait Implementations
Sourceimpl RawPointerConverter<CTrsIterator> for CTrsIterator
impl RawPointerConverter<CTrsIterator> for CTrsIterator
Sourcefn into_raw_pointer(self) -> *const CTrsIterator
fn into_raw_pointer(self) -> *const CTrsIterator
Creates a raw pointer from the value and leaks it, you should use
Self::from_raw_pointer
or Self::drop_raw_pointer to free the value when you’re done with it.Sourcefn into_raw_pointer_mut(self) -> *mut CTrsIterator
fn into_raw_pointer_mut(self) -> *mut CTrsIterator
Creates a mutable raw pointer from the value and leaks it, you should use
Self::from_raw_pointer_mut or Self::drop_raw_pointer_mut to free the value when
you’re done with it.Sourceunsafe fn from_raw_pointer_mut(
input: *mut CTrsIterator,
) -> Result<CTrsIterator, UnexpectedNullPointerError>
unsafe fn from_raw_pointer_mut( input: *mut CTrsIterator, ) -> Result<CTrsIterator, UnexpectedNullPointerError>
Takes back control of a raw pointer created by
Self::into_raw_pointer_mut. Read moreSourceunsafe fn from_raw_pointer(
input: *const CTrsIterator,
) -> Result<CTrsIterator, UnexpectedNullPointerError>
unsafe fn from_raw_pointer( input: *const CTrsIterator, ) -> Result<CTrsIterator, UnexpectedNullPointerError>
Takes back control of a raw pointer created by
Self::into_raw_pointer. Read moreSourceunsafe fn drop_raw_pointer(
input: *const T,
) -> Result<(), UnexpectedNullPointerError>
unsafe fn drop_raw_pointer( input: *const T, ) -> Result<(), UnexpectedNullPointerError>
Takes back control of a raw pointer created by
Self::into_raw_pointer and drop it. Read moreSourceunsafe fn drop_raw_pointer_mut(
input: *mut T,
) -> Result<(), UnexpectedNullPointerError>
unsafe fn drop_raw_pointer_mut( input: *mut T, ) -> Result<(), UnexpectedNullPointerError>
Takes back control of a raw pointer created by
Self::into_raw_pointer_mut and drops it. Read moreAuto Trait Implementations
impl Freeze for CTrsIterator
impl RefUnwindSafe for CTrsIterator
impl Send for CTrsIterator
impl Sync for CTrsIterator
impl Unpin for CTrsIterator
impl UnsafeUnpin for CTrsIterator
impl UnwindSafe for CTrsIterator