pub struct CTrs(/* private fields */);Trait Implementations
Sourceimpl RawPointerConverter<CTrs> for CTrs
impl RawPointerConverter<CTrs> for CTrs
Sourcefn into_raw_pointer(self) -> *const CTrs
fn into_raw_pointer(self) -> *const CTrs
Creates a raw pointer from the value and leaks it, you should use
Self::from_raw_pointer
or Self::drop_raw_pointer to free the value when you’re done with it.Sourcefn into_raw_pointer_mut(self) -> *mut CTrs
fn into_raw_pointer_mut(self) -> *mut CTrs
Creates a mutable raw pointer from the value and leaks it, you should use
Self::from_raw_pointer_mut or Self::drop_raw_pointer_mut to free the value when
you’re done with it.Sourceunsafe fn from_raw_pointer_mut(
input: *mut CTrs,
) -> Result<CTrs, UnexpectedNullPointerError>
unsafe fn from_raw_pointer_mut( input: *mut CTrs, ) -> Result<CTrs, UnexpectedNullPointerError>
Takes back control of a raw pointer created by
Self::into_raw_pointer_mut. Read moreSourceunsafe fn from_raw_pointer(
input: *const CTrs,
) -> Result<CTrs, UnexpectedNullPointerError>
unsafe fn from_raw_pointer( input: *const CTrs, ) -> Result<CTrs, UnexpectedNullPointerError>
Takes back control of a raw pointer created by
Self::into_raw_pointer. Read moreSourceunsafe fn drop_raw_pointer(
input: *const T,
) -> Result<(), UnexpectedNullPointerError>
unsafe fn drop_raw_pointer( input: *const T, ) -> Result<(), UnexpectedNullPointerError>
Takes back control of a raw pointer created by
Self::into_raw_pointer and drop it. Read moreSourceunsafe fn drop_raw_pointer_mut(
input: *mut T,
) -> Result<(), UnexpectedNullPointerError>
unsafe fn drop_raw_pointer_mut( input: *mut T, ) -> Result<(), UnexpectedNullPointerError>
Takes back control of a raw pointer created by
Self::into_raw_pointer_mut and drops it. Read moreAuto Trait Implementations
impl Freeze for CTrs
impl RefUnwindSafe for CTrs
impl Send for CTrs
impl Sync for CTrs
impl Unpin for CTrs
impl UnsafeUnpin for CTrs
impl UnwindSafe for CTrs